==> google_cloud_securitycenter-1.25.0-py2.py3-none-any.whl: google/cloud/securitycenter_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.securitycenter_v1 import gapic_version as package_version

__version__ = package_version.__version__


from .services.security_center import SecurityCenterAsyncClient, SecurityCenterClient
from .types.access import Access, Geolocation, ServiceAccountDelegationInfo
from .types.asset import Asset
from .types.bigquery_export import BigQueryExport
from .types.cloud_dlp_data_profile import CloudDlpDataProfile
from .types.cloud_dlp_inspection import CloudDlpInspection
from .types.compliance import Compliance
from .types.connection import Connection
from .types.contact_details import Contact, ContactDetails
from .types.container import Container
from .types.database import Database
from .types.effective_security_health_analytics_custom_module import (
    EffectiveSecurityHealthAnalyticsCustomModule,
)
from .types.exfiltration import ExfilResource, Exfiltration
from .types.external_system import ExternalSystem
from .types.file import File
from .types.finding import Finding
from .types.folder import Folder
from .types.iam_binding import IamBinding
from .types.indicator import Indicator
from .types.kernel_rootkit import KernelRootkit
from .types.kubernetes import Kubernetes
from .types.label import Label
from .types.mitre_attack import MitreAttack
from .types.mute_config import MuteConfig
from .types.notification_config import NotificationConfig
from .types.notification_message import NotificationMessage
from .types.organization_settings import OrganizationSettings
from .types.process import EnvironmentVariable, Process
from .types.resource import Resource
from .types.run_asset_discovery_response import RunAssetDiscoveryResponse
from .types.security_health_analytics_custom_config import CustomConfig
from .types.security_health_analytics_custom_module import (
    SecurityHealthAnalyticsCustomModule,
)
from .types.security_marks import SecurityMarks
from .types.securitycenter_service import (
    BulkMuteFindingsRequest,
    BulkMuteFindingsResponse,
    CreateBigQueryExportRequest,
    CreateFindingRequest,
    CreateMuteConfigRequest,
    CreateNotificationConfigRequest,
    CreateSecurityHealthAnalyticsCustomModuleRequest,
    CreateSourceRequest,
    DeleteBigQueryExportRequest,
    DeleteMuteConfigRequest,
    DeleteNotificationConfigRequest,
    DeleteSecurityHealthAnalyticsCustomModuleRequest,
    GetBigQueryExportRequest,
    GetEffectiveSecurityHealthAnalyticsCustomModuleRequest,
    GetMuteConfigRequest,
    GetNotificationConfigRequest,
    GetOrganizationSettingsRequest,
    GetSecurityHealthAnalyticsCustomModuleRequest,
    GetSourceRequest,
    GroupAssetsRequest,
    GroupAssetsResponse,
    GroupFindingsRequest,
    GroupFindingsResponse,
    GroupResult,
    ListAssetsRequest,
    ListAssetsResponse,
    ListBigQueryExportsRequest,
    ListBigQueryExportsResponse,
    ListDescendantSecurityHealthAnalyticsCustomModulesRequest,
    ListDescendantSecurityHealthAnalyticsCustomModulesResponse,
    ListEffectiveSecurityHealthAnalyticsCustomModulesRequest,
    ListEffectiveSecurityHealthAnalyticsCustomModulesResponse,
    ListFindingsRequest,
    ListFindingsResponse,
    ListMuteConfigsRequest,
    ListMuteConfigsResponse,
    ListNotificationConfigsRequest,
    ListNotificationConfigsResponse,
    ListSecurityHealthAnalyticsCustomModulesRequest,
    ListSecurityHealthAnalyticsCustomModulesResponse,
    ListSourcesRequest,
    ListSourcesResponse,
    RunAssetDiscoveryRequest,
    SetFindingStateRequest,
    SetMuteRequest,
    SimulateSecurityHealthAnalyticsCustomModuleRequest,
    SimulateSecurityHealthAnalyticsCustomModuleResponse,
    UpdateBigQueryExportRequest,
    UpdateExternalSystemRequest,
    UpdateFindingRequest,
    UpdateMuteConfigRequest,
    UpdateNotificationConfigRequest,
    UpdateOrganizationSettingsRequest,
    UpdateSecurityHealthAnalyticsCustomModuleRequest,
    UpdateSecurityMarksRequest,
    UpdateSourceRequest,
)
from .types.source import Source
from .types.vulnerability import Cve, Cvssv3, Reference, Vulnerability

__all__ = (
    "SecurityCenterAsyncClient",
    "Access",
    "Asset",
    "BigQueryExport",
    "BulkMuteFindingsRequest",
    "BulkMuteFindingsResponse",
    "CloudDlpDataProfile",
    "CloudDlpInspection",
    "Compliance",
    "Connection",
    "Contact",
    "ContactDetails",
    "Container",
    "CreateBigQueryExportRequest",
    "CreateFindingRequest",
    "CreateMuteConfigRequest",
    "CreateNotificationConfigRequest",
    "CreateSecurityHealthAnalyticsCustomModuleRequest",
    "CreateSourceRequest",
    "CustomConfig",
    "Cve",
    "Cvssv3",
    "Database",
    "DeleteBigQueryExportRequest",
    "DeleteMuteConfigRequest",
    "DeleteNotificationConfigRequest",
    "DeleteSecurityHealthAnalyticsCustomModuleRequest",
    "EffectiveSecurityHealthAnalyticsCustomModule",
    "EnvironmentVariable",
    "ExfilResource",
    "Exfiltration",
    "ExternalSystem",
    "File",
    "Finding",
    "Folder",
    "Geolocation",
    "GetBigQueryExportRequest",
    "GetEffectiveSecurityHealthAnalyticsCustomModuleRequest",
    "GetMuteConfigRequest",
    "GetNotificationConfigRequest",
    "GetOrganizationSettingsRequest",
    "GetSecurityHealthAnalyticsCustomModuleRequest",
    "GetSourceRequest",
    "GroupAssetsRequest",
    "GroupAssetsResponse",
    "GroupFindingsRequest",
    "GroupFindingsResponse",
    "GroupResult",
    "IamBinding",
    "Indicator",
    "KernelRootkit",
    "Kubernetes",
    "Label",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListBigQueryExportsRequest",
    "ListBigQueryExportsResponse",
    "ListDescendantSecurityHealthAnalyticsCustomModulesRequest",
    "ListDescendantSecurityHealthAnalyticsCustomModulesResponse",
    "ListEffectiveSecurityHealthAnalyticsCustomModulesRequest",
    "ListEffectiveSecurityHealthAnalyticsCustomModulesResponse",
    "ListFindingsRequest",
    "ListFindingsResponse",
    "ListMuteConfigsRequest",
    "ListMuteConfigsResponse",
    "ListNotificationConfigsRequest",
    "ListNotificationConfigsResponse",
    "ListSecurityHealthAnalyticsCustomModulesRequest",
    "ListSecurityHealthAnalyticsCustomModulesResponse",
    "ListSourcesRequest",
    "ListSourcesResponse",
    "MitreAttack",
    "MuteConfig",
    "NotificationConfig",
    "NotificationMessage",
    "OrganizationSettings",
    "Process",
    "Reference",
    "Resource",
    "RunAssetDiscoveryRequest",
    "RunAssetDiscoveryResponse",
    "SecurityCenterClient",
    "SecurityHealthAnalyticsCustomModule",
    "SecurityMarks",
    "ServiceAccountDelegationInfo",
    "SetFindingStateRequest",
    "SetMuteRequest",
    "SimulateSecurityHealthAnalyticsCustomModuleRequest",
    "SimulateSecurityHealthAnalyticsCustomModuleResponse",
    "Source",
    "UpdateBigQueryExportRequest",
    "UpdateExternalSystemRequest",
    "UpdateFindingRequest",
    "UpdateMuteConfigRequest",
    "UpdateNotificationConfigRequest",
    "UpdateOrganizationSettingsRequest",
    "UpdateSecurityHealthAnalyticsCustomModuleRequest",
    "UpdateSecurityMarksRequest",
    "UpdateSourceRequest",
    "Vulnerability",
)

==> google_cloud_securitycenter-1.30.1-py2.py3-none-any.whl: google/cloud/securitycenter_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.securitycenter_v1 import gapic_version as package_version

__version__ = package_version.__version__


from .services.security_center import SecurityCenterAsyncClient, SecurityCenterClient
from .types.access import Access, Geolocation, ServiceAccountDelegationInfo
from .types.application import Application
from .types.asset import Asset
from .types.backup_disaster_recovery import BackupDisasterRecovery
from .types.bigquery_export import BigQueryExport
from .types.cloud_dlp_data_profile import CloudDlpDataProfile
from .types.cloud_dlp_inspection import CloudDlpInspection
from .types.compliance import Compliance
from .types.connection import Connection
from .types.contact_details import Contact, ContactDetails
from .types.container import Container
from .types.database import Database
from .types.effective_security_health_analytics_custom_module import (
    EffectiveSecurityHealthAnalyticsCustomModule,
)
from .types.exfiltration import ExfilResource, Exfiltration
from .types.external_system import ExternalSystem
from .types.file import File
from .types.finding import Finding
from .types.folder import Folder
from .types.iam_binding import IamBinding
from .types.indicator import Indicator
from .types.kernel_rootkit import KernelRootkit
from .types.kubernetes import Kubernetes
from .types.label import Label
from .types.load_balancer import LoadBalancer
from .types.log_entry import CloudLoggingEntry, LogEntry
from .types.mitre_attack import MitreAttack
from .types.mute_config import MuteConfig
from .types.notebook import Notebook
from .types.notification_config import NotificationConfig
from .types.notification_message import NotificationMessage
from .types.org_policy import OrgPolicy
from .types.organization_settings import OrganizationSettings
from .types.process import EnvironmentVariable, Process
from .types.resource import Resource
from .types.run_asset_discovery_response import RunAssetDiscoveryResponse
from .types.security_health_analytics_custom_config import CustomConfig
from .types.security_health_analytics_custom_module import (
    SecurityHealthAnalyticsCustomModule,
)
from .types.security_marks import SecurityMarks
from .types.security_posture import SecurityPosture
from .types.securitycenter_service import (
    BulkMuteFindingsRequest,
    BulkMuteFindingsResponse,
    CreateBigQueryExportRequest,
    CreateFindingRequest,
    CreateMuteConfigRequest,
    CreateNotificationConfigRequest,
    CreateSecurityHealthAnalyticsCustomModuleRequest,
    CreateSourceRequest,
    DeleteBigQueryExportRequest,
    DeleteMuteConfigRequest,
    DeleteNotificationConfigRequest,
    DeleteSecurityHealthAnalyticsCustomModuleRequest,
    GetBigQueryExportRequest,
    GetEffectiveSecurityHealthAnalyticsCustomModuleRequest,
    GetMuteConfigRequest,
    GetNotificationConfigRequest,
    GetOrganizationSettingsRequest,
    GetSecurityHealthAnalyticsCustomModuleRequest,
    GetSourceRequest,
    GroupAssetsRequest,
    GroupAssetsResponse,
    GroupFindingsRequest,
    GroupFindingsResponse,
    GroupResult,
    ListAssetsRequest,
    ListAssetsResponse,
    ListBigQueryExportsRequest,
    ListBigQueryExportsResponse,
    ListDescendantSecurityHealthAnalyticsCustomModulesRequest,
    ListDescendantSecurityHealthAnalyticsCustomModulesResponse,
    ListEffectiveSecurityHealthAnalyticsCustomModulesRequest,
    ListEffectiveSecurityHealthAnalyticsCustomModulesResponse,
    ListFindingsRequest,
    ListFindingsResponse,
    ListMuteConfigsRequest,
    ListMuteConfigsResponse,
    ListNotificationConfigsRequest,
    ListNotificationConfigsResponse,
    ListSecurityHealthAnalyticsCustomModulesRequest,
    ListSecurityHealthAnalyticsCustomModulesResponse,
    ListSourcesRequest,
    ListSourcesResponse,
    RunAssetDiscoveryRequest,
    SetFindingStateRequest,
    SetMuteRequest,
    SimulateSecurityHealthAnalyticsCustomModuleRequest,
    SimulateSecurityHealthAnalyticsCustomModuleResponse,
    UpdateBigQueryExportRequest,
    UpdateExternalSystemRequest,
    UpdateFindingRequest,
    UpdateMuteConfigRequest,
    UpdateNotificationConfigRequest,
    UpdateOrganizationSettingsRequest,
    UpdateSecurityHealthAnalyticsCustomModuleRequest,
    UpdateSecurityMarksRequest,
    UpdateSourceRequest,
)
from .types.source import Source
from .types.vulnerability import (
    Cve,
    Cvssv3,
    Package,
    Reference,
    SecurityBulletin,
    Vulnerability,
)

__all__ = (
    "SecurityCenterAsyncClient",
    "Access",
    "Application",
    "Asset",
    "BackupDisasterRecovery",
    "BigQueryExport",
    "BulkMuteFindingsRequest",
    "BulkMuteFindingsResponse",
    "CloudDlpDataProfile",
    "CloudDlpInspection",
    "CloudLoggingEntry",
    "Compliance",
    "Connection",
    "Contact",
    "ContactDetails",
    "Container",
    "CreateBigQueryExportRequest",
    "CreateFindingRequest",
    "CreateMuteConfigRequest",
    "CreateNotificationConfigRequest",
    "CreateSecurityHealthAnalyticsCustomModuleRequest",
    "CreateSourceRequest",
    "CustomConfig",
    "Cve",
    "Cvssv3",
    "Database",
    "DeleteBigQueryExportRequest",
    "DeleteMuteConfigRequest",
    "DeleteNotificationConfigRequest",
    "DeleteSecurityHealthAnalyticsCustomModuleRequest",
    "EffectiveSecurityHealthAnalyticsCustomModule",
    "EnvironmentVariable",
    "ExfilResource",
    "Exfiltration",
    "ExternalSystem",
    "File",
    "Finding",
    "Folder",
    "Geolocation",
    "GetBigQueryExportRequest",
    "GetEffectiveSecurityHealthAnalyticsCustomModuleRequest",
    "GetMuteConfigRequest",
    "GetNotificationConfigRequest",
    "GetOrganizationSettingsRequest",
    "GetSecurityHealthAnalyticsCustomModuleRequest",
    "GetSourceRequest",
    "GroupAssetsRequest",
    "GroupAssetsResponse",
    "GroupFindingsRequest",
    "GroupFindingsResponse",
    "GroupResult",
    "IamBinding",
    "Indicator",
    "KernelRootkit",
    "Kubernetes",
    "Label",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListBigQueryExportsRequest",
    "ListBigQueryExportsResponse",
    "ListDescendantSecurityHealthAnalyticsCustomModulesRequest",
    "ListDescendantSecurityHealthAnalyticsCustomModulesResponse",
    "ListEffectiveSecurityHealthAnalyticsCustomModulesRequest",
    "ListEffectiveSecurityHealthAnalyticsCustomModulesResponse",
    "ListFindingsRequest",
    "ListFindingsResponse",
    "ListMuteConfigsRequest",
    "ListMuteConfigsResponse",
    "ListNotificationConfigsRequest",
    "ListNotificationConfigsResponse",
    "ListSecurityHealthAnalyticsCustomModulesRequest",
    "ListSecurityHealthAnalyticsCustomModulesResponse",
    "ListSourcesRequest",
    "ListSourcesResponse",
    "LoadBalancer",
    "LogEntry",
    "MitreAttack",
    "MuteConfig",
    "Notebook",
    "NotificationConfig",
    "NotificationMessage",
    "OrgPolicy",
    "OrganizationSettings",
    "Package",
    "Process",
    "Reference",
    "Resource",
    "RunAssetDiscoveryRequest",
    "RunAssetDiscoveryResponse",
    "SecurityBulletin",
    "SecurityCenterClient",
    "SecurityHealthAnalyticsCustomModule",
    "SecurityMarks",
    "SecurityPosture",
    "ServiceAccountDelegationInfo",
    "SetFindingStateRequest",
    "SetMuteRequest",
    "SimulateSecurityHealthAnalyticsCustomModuleRequest",
    "SimulateSecurityHealthAnalyticsCustomModuleResponse",
    "Source",
    "UpdateBigQueryExportRequest",
    "UpdateExternalSystemRequest",
    "UpdateFindingRequest",
    "UpdateMuteConfigRequest",
    "UpdateNotificationConfigRequest",
    "UpdateOrganizationSettingsRequest",
    "UpdateSecurityHealthAnalyticsCustomModuleRequest",
    "UpdateSecurityMarksRequest",
    "UpdateSourceRequest",
    "Vulnerability",
)
